.. _literal_example-name:

!!!!!!!!!!!!!!!
literal_example
!!!!!!!!!!!!!!!

.. meta::
  :keywords: literal_example,literal,command,example,prototype,t,factorial,square,tangent,xrst_literal,this,file

.. index:: literal_example, literal

.. _literal_example-title:

Literal Command Example
#######################
This example is similar to the :ref:`dir_example-name` .

.. contents::
  :local:

.. index:: prototype

.. _literal_example@Prototype:

Prototype
*********

.. literalinclude:: ../../example/literal.cpp
  :lines: 6-6,14-14,19-19
  :language: cpp

.. index:: t

.. _literal_example@T:

T
*
This is a numeric type that is used for the calculation.

.. index:: factorial

.. _literal_example@factorial:

factorial
*********
Returns the factorial of its argument *n* .

.. index:: square

.. _literal_example@square:

square
******
Returns the square of its argument *x* .

.. index:: tangent

.. _literal_example@tangent:

tangent
*******
Returns the tangent corresponding to its argument *x* .

.. index:: xrst_literal

.. _literal_example@xrst_literal:

xrst_literal
************
The file below demonstrates the use of ``xrst_literal`` .

.. _literal_example@This Example File:

This Example File
*****************

.. literalinclude:: ../../example/literal.cpp
  :language: cpp
